window.Gleam.initSearch([{"doc":"glychee","title":"glychee","content":"# Glychee · A Simple Gleam Benchmark Runner\n\n[![Hex Package](https://img.shields.io/hexpm/v/glychee?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glychee)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glychee/)\n[![License](https://img.shields.io/hexpm/l/glychee?color=ffaff3&amp;label=%F0%9F%93%83)](https://github.com/inoas/glychee/blob/main/LICENSE)\n\nA simple [Gleam](https://gleam.run) benchmark runner which wraps [**Benchee**](https://github.com/bencheeorg/benchee) for the heavy lifting.\n\nNamed after *Gleam*, *Benchee* and their fruity [*Lychee*](https://en.wikipedia.org/wiki/Lychee) offspring:\n\n&lt;figure&gt;\n  &lt;img src=&quot;https://raw.githubusercontent.com/inoas/glychee/main/glychee-logo.jpg&quot; alt=&quot;Glychee Logo&quot; style=&quot;max-height: 33vh; width: auto; height: auto&quot; width=&quot;480&quot; height=&quot;480&quot;/&gt;\n  &lt;figcaption&gt;&lt;i&gt;&lt;small&gt;Imaginary Glychees&lt;/small&gt;&lt;/i&gt;&lt;/figcaption&gt;\n&lt;/figure&gt;\n\n## Requirements\n\n- Requires **Gleam 1.0** or later.\n- For benchmarking on target JavaScript see &lt;https://hex.pm/packages/gleamy_bench&gt;,\n  as Glychee only allows benchmarking on target Erlang.\n- Glychee is dependency free except for *Benchee* and *Elixir*.\n- A recent Elixir and Hex must be installed. You might be required to run\n  `mix local.hex` after installing Elixir.\n\n## Quick start\n\n1. Add ***Glychee*** to your project: `gleam add glychee --dev`.\n2. Create a custom benchmarking module for example named `my_benchmark` that\n   contains a `main`-function. In that module you will define which `Function`s\n   to benchmark with one or many `Data`.\n3. Run the benchmark:\n\n   ```shell\n   gleam clean &amp;&amp; \\\n   gleam build &amp;&amp; \\\n   gleam run -m my_benchmark\n   ```\n\n### Full example\n\nIf you do not have a Gleam project yet, create it with:\n\n```shell\ngleam new foobar\ncd foobar\n```\n\nTo add and run a demo of **Glychee**:\n\n1. `gleam add glychee --dev`\n2. In your project create a file named `src/my_benchmark.gleam` with following source code:\n\n   ```gleam\n   import gleam/int\n   import gleam/list\n   import glychee/benchmark\n\n   pub fn main() {\n     benchmark.run(\n       [\n         benchmark.Function(label: &quot;list.sort()&quot;, callable: fn(test_data) {\n           fn() { list.sort(test_data, int.compare) }\n         }),\n       ],\n       [\n         benchmark.Data(label: &quot;pre-sorted list&quot;, data: list.range(1, 100_000)),\n         benchmark.Data(\n           label: &quot;reversed list&quot;,\n           data: list.range(1, 100_000)\n             |&gt; list.reverse,\n         ),\n       ],\n     )\n   }\n   ```\n\n3. Then run in your terminal via:\n\n   ```shell\n   gleam clean &amp;&amp; \\\n   gleam build &amp;&amp; \\\n   gleam run -m my_benchmark\n   ```\n\nNow you can alter the functions and data specified in above&#39;s example to\nwhichever function of your application or library you want to benchmark.\n\nNote that you can benchmark multiple functions with different data sets\nin one go.\n\n## Documentation\n\n**Glychee**&#39;s documentation can be found at &lt;https://hexdocs.pm/glychee&gt;.\n\n## License\n\n[Apache 2.0](./LICENSE)\n","url":"index.html"},{"doc":"glychee","title":"glychee","content":"# Changelog\n\n## 1.0.2 - 2024-02-27\n\n- Fix hiding of internals.\n\n## 1.0.1 - 2024-02-27\n\n- Mark helpers module as internal.\n\n## 1.0.0 - 2024-02-27\n\n- Update for **Gleam** `~&gt; 1.0`.\n- Some code cleanup and refactorings.\n- Also updates Benchee dep to `~&gt; 1.3`.\n\n## 0.3.0 - 2023-06-14\n\n- Update for **Gleam** `~&gt; 0.30`.\n\n## 0.2.7 - 2023-01-20\n\n- Improved readme instructions on how to run the Glychee.\n\n## 0.2.6 - 2023-01-01\n\n- Instruct to use `gleam add glychee --dev` to add as a dev dependency, only.\n\n## 0.2.5 - 2023-01-01\n\n- Fix logo on *hexpm*.\n\n## 0.2.4 - 2023-01-01\n\n- Readme\n- Typos\n- Logo\n\n## 0.2.3 - 2022-10-25\n\n- Now just requires Gleam 0.24.0 instead of an unreleased nightly version.\n\n## 0.2.2 - 2022-10-25\n\n- Changed Benchee configuration settings to:\n\n  ```elixir\n  [\n    warmup: 4,\n    time: 8,\n    memory_time: 4,\n    reduction_time: 4\n  ]\n  ```\n\n## v0.2.0 - 2022-10-21\n\n- Removed these dependencies: gleam&#39;s `stdlib`, `gleam_erlang`, and `gleeunit`,\n  which means Glychee can be used in these projects to benchmark themselves.\n","url":"changelog.html"},{"doc":"glychee","title":"glychee","content":"                                 Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      &quot;License&quot; shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      &quot;Legal Entity&quot; shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      &quot;control&quot; means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      &quot;Source&quot; form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      &quot;Object&quot; form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      &quot;Work&quot; shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      &quot;Contribution&quot; shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, &quot;submitted&quot;\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;\n\n      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n","url":"license.html"},{"doc":"glychee/benchmark","title":"Data","content":"pub type Data(data) {\n  Data(label: String, data: data)\n}\n Data pairs arbitrary data to benchmark on with a label.\n\n The label is used as part of the benchmark&#39;s `stdout` output.\n\nData(label: String, data: data)\n\n\nSynonyms:\nglychee/benchmark.Data\nglychee/benchmark Data","url":"glychee/benchmark.html#Data"},{"doc":"glychee/benchmark","title":"Function","content":"pub type Function(test_data, any) {\n  Function(label: String, callable: fn(test_data) -&gt; fn() -&gt; any)\n}\n Function pairs a `label` with a function returning a callable.\n\n The function requires some `test_data`.\n\n The label is used as part of the benchmark&#39;s stdout output.\n\nFunction(label: String, callable: fn(test_data) -&gt; fn() -&gt; any)\n\n\nSynonyms:\nglychee/benchmark.Function\nglychee/benchmark Function","url":"glychee/benchmark.html#Function"},{"doc":"glychee/benchmark","title":"run","content":"pub fn run(\n  function_list: List(Function(a, b)),\n  data_list: List(Data(a)),\n) -&gt; Nil\n Takes a `List` of `Function` and `List` of `Data` and runs benchmarks for each\n `Function` combined with each `Data` grouped by `Data` first and `Function`\n second.\n\n Utilizes `Benchee` and its `stdout`&#39;s output to print the function&#39;s benchmark\n results for all data.\n\nSynonyms:\nglychee/benchmark.run\nglychee/benchmark run","url":"glychee/benchmark.html#run"},{"doc":"glychee/benchmark","title":"glychee/benchmark","content":" Contains custom types `Function` and `Data` and a runner function to run\n a list of these benchmark functions against a list of benchmark data.\n","url":"glychee/benchmark.html"}]);